# IFS_explorer
_A python3 visualization tool for integral field spectroscopy (IFS) data_
### Installation
To install the IFS_explorer package:
```
pip install IFS-explorer
```
or:
```
pip3 install IFS-explorer
```
(depending on the version)


Once installed, run in any python terminal:
```
from IFS_explorer import *
x = IFS_explorer()
```

This is work in progress, for any comments and contributions drop an email to: frosales@cantab.net

